@@ -64,7 +64,10 @@ class Renderer ():
         for team in script.by_team:
             if len(script.by_team[team]) > 0:
                 to_add.put(team)
-        to_add.put('jinxes')
+    
+        # If we want jinxes to flow, we should try to cram it too.
+        if not script.options.force_jinxes:
+            to_add.put('jinxes')
         
         page_groups = [{ "teams": [], "height": 0 }]
         
@@ -79,6 +82,14 @@ class Renderer ():
             else:
                 page_groups.append({ "teams": [next_team], "height": current_height })
 
+        # If we always want jinxes on a new page
+        if script.options.force_jinxes:
+            page_groups.append({ "teams": ["jinxes"], "height": 0 })
+        
+        jinxes_next_page = len(page_groups[-1]["teams"]) == 1 or script.options.force_jinxes
+        if jinxes_next_page:
+            page_groups.pop()
+
         # Decide where we'll build icons.
         workspace = output_folder
 
@@ -91,20 +102,36 @@ class Renderer ():
         needs_spacers = { team: len(script.by_team[team]) == 1 for team in script.by_team }
         
         # Calculate spacers for large team names.
-        for team in ['outsider', 'traveler']:
+        for team in ['townsfolk', 'outsider', 'traveler']:
             needs_spacers[team] = len(script.by_team[team]) <= 2
 
+        def num_spacers(team):
+            match team:
+                case 'townsfolk' | 'outsider' | 'traveler':
+                    return 7
+                case 'fabled':
+                    return 4
+                case _:
+                    return 5
+
+        spacers = { team: num_spacers(team) for team in needs_spacers if needs_spacers[team] is True }
+
+        for team in ['townsfolk', 'outsider', 'traveler']:
+            if len(script.by_team[team]) == 2:
+                spacers[team] = 1
+
         # Pass configuration forwards to jinja/weasyprint stack.  
         params = {
             "pages": [ group['teams'] for group in page_groups ],
             "characters": { character.id: character for character in script.characters },
             "abilities": abilities,
-            "spacers": needs_spacers,
+            "spacers": spacers,
             "teams": script.by_team,
             "icons": { id: f"file://{icon.path(Path(workspace.parent, 'build', 'icons').resolve())}" for id, icon in script.data.icons.items() },
             "logo": f"file://{script.meta.icon.path(Path(workspace.parent, 'build').resolve())}" if script.meta.icon else "",
             "jinxes": script.jinxes,
             "has_jinxes": sum([ len(jinxes) for id, jinxes in script.jinxes.items() ]) > 0,
+            "jinxes_next_page": jinxes_next_page,
             "meta": script.meta,
             "options": script.options
         }
